@@ -257,11 +257,13 @@ public class HwpRecord_BorderFill extends HwpRecord {
                 diagonal = getBorder(child); break;
             case "hc:fillBrush":
                 fill = readFillBrush(child); break;
+            case "#text":
+                break;
             default:
-            	if (log.isLoggable(Level.FINE)) {
-            		throw new NotImplementedException("HwpRecord_BorderFill");
-            	}
-            	break;
+                if (log.isLoggable(Level.FINE)) {
+                    throw new NotImplementedException("HwpRecord_BorderFill");
+                }
+                break;
             }
         }
     }
@@ -275,7 +277,7 @@ public class HwpRecord_BorderFill extends HwpRecord {
         // [color="none", type="NONE", width="0.1 mm"]
         
         border.style = LineStyle2.valueOf(childAttrs.getNamedItem("type").getNodeValue());
-        String colorStr = childAttrs.getNamedItem("color").getNodeValue().replaceAll("^#([0-9A-F]+)$", "$1");
+        String colorStr = childAttrs.getNamedItem("color").getNodeValue().replaceAll("^#([0-9A-Fa-f]+)$", "$1");
         if (!colorStr.equals("none")) {
         	border.color = Integer.parseUnsignedInt(colorStr, 16);      // RGBColor (0xRRGGBB) 값으로 저장
         }
@@ -351,6 +353,8 @@ public class HwpRecord_BorderFill extends HwpRecord {
                 readImgBrush(grandChild, fill);
                 fill.fillType = fill.fillType | 0x02;
                 break;
+            case "#text":
+                break;
             default:
             	if (log.isLoggable(Level.FINE)) {
             		throw new NotImplementedException("readFillBrush");
@@ -381,22 +385,6 @@ public class HwpRecord_BorderFill extends HwpRecord {
             fill.hatchStyle = ColorFillPattern.NONE;
         } else {
             fill.hatchStyle = ColorFillPattern.valueOf(childAttrs.getNamedItem("hatchStyle").getNodeValue());
-            /*
-            switch(childAttrs.getNamedItem("hatchStyle").getNodeValue()) {
-            case "HORIZONTAL":
-                fill.hatchStyle = ColorFillPattern.HORIZONTAL;  break;
-            case "VERTICAL":
-                fill.hatchStyle = ColorFillPattern.VERTICAL;    break;
-            case "BACK_SLASH":
-                fill.hatchStyle = ColorFillPattern.BACK_SLASH;  break;
-            case "SLASH":
-                fill.hatchStyle = ColorFillPattern.SLASH;       break;
-            case "CROSS":
-                fill.hatchStyle = ColorFillPattern.CROSS;       break;
-            case "CROSS_DIAGONAL":
-                fill.hatchStyle = ColorFillPattern.CROSS_DIAGONAL;  break;
-            }
-            */
         }
             
         colorStr = childAttrs.getNamedItem("alpha").getNodeValue();
