@@ -20,12 +20,6 @@
  */
 package soffice;
 
-import java.awt.image.BufferedImage;
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.net.URL;
-import java.nio.file.Files;
-import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -35,8 +29,6 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.logging.Logger;
 
-import javax.imageio.ImageIO;
-
 import com.sun.star.awt.FontDescriptor;
 import com.sun.star.awt.XDevice;
 import com.sun.star.awt.XToolkit;
@@ -146,15 +138,14 @@ public class ConvPage {
             XDevice device = xToolkit.createScreenCompatibleDevice(0, 0);
             FontDescriptor[] fds = device.getFontDescriptors();
 
-            Set<String> namesSet = new HashSet<String>();
             for (int i = 0; i < fds.length; i++) {
-                namesSet.add(fds[i].Name);
+                WriterContext.fontNameSet.add(fds[i].Name);
             }
 
             for (int i = 0; i < wContext.getDocInfo().charShapeList.size(); i++) {
                 HwpRecord_CharShape font = (HwpRecord_CharShape) wContext.getDocInfo().charShapeList.get(i);
 
-                if (font.fontName[0]!=null && namesSet.contains(font.fontName[0])==false) {
+                if (font.fontName[0]!=null && WriterContext.fontNameSet.contains(font.fontName[0])==false) {
                     String replaceFontName = null;
 
                     // 한컴 전용폰트이므로, 대체폰트로 교체.
@@ -201,7 +192,7 @@ public class ConvPage {
                         replaceFontName = "나눔고딕";
                     }
                     for (int j = 0; j < font.fontName.length; j++) {
-                        if (namesSet.contains(replaceFontName)) {
+                        if (WriterContext.fontNameSet.contains(replaceFontName)) {
                             log.fine("Font[" + font.fontName[j] + "] does not exist. so replacing with basic Font["
                                     + replaceFontName + "]");
                             font.fontName[j] = replaceFontName;
